function Reyn = PipeReynolds(flow_rate, diameter, density, viscosity)
%PipeReynolds calculates the Reynolds number for flow in a circular pipe
%  Reyn = PipeReynolds(flow_rate, diameter, density, viscosity)
%  Reyn      is the Reynolds number
%  flow_rate is the volumetric flow, in m^3/sec
%       note gpm/15840 is m^3/sec
%  diameter  is the pipe diameter, in meters
%  density   is the fluid density, kg/m^3, 900 is value for hydraulic fluid 
%  viscosity is the fluid viscosity, in kg m^-1 s^-1, for mineral oil, it is .1
%      note .1 kg m^-1 s^-1 = 1 poise (g cm^-1 s^-1)

% Reynold = V*D*den/vis   V is velocity, D is pipe diameter
% V = flow_rate/((pi*(D/2)^2))
% V = flow_rate*4/pi*D^2
%  so
% R = (4/pi) * (flow_rate*den)/(D*vis)

% BTL Jan 17 2002

Reyn = (4/pi)*(flow_rate*density)/(diameter*viscosity);
